@@ -32,12 +32,14 @@
 #include <QThread>
 #include <QHash>
 #include <QFileInfo>
+#include <QFile>
 #include <QDir>
 #include <QFileSystemWatcher>
 #include <QMimeDatabase>
 #include <QSet>
 #include <QPair>
 #include <QAtomicInt>
+#include <QDebug>
 
 #include <QtGlobal>
 
@@ -60,20 +62,22 @@ public:
 
     QString mSourceName;
 
-    bool mHandleNewFiles = true;
-
     KFileMetaData::ExtractorCollection mExtractors;
 
-    QAtomicInt mStopRequest = 0;
-
     QMimeDatabase mMimeDb;
 
+    QHash<QUrl, QDateTime> mAllFiles;
+
+    QAtomicInt mStopRequest = 0;
+
     int mImportedTracksCount = 0;
 
     int mNotificationUpdateInterval = 1;
 
     int mNewFilesEmitInterval = 1;
 
+    bool mHandleNewFiles = true;
+
 };
 
 AbstractFileListing::AbstractFileListing(const QString &sourceName, QObject *parent) : QObject(parent), d(std::make_unique<AbstractFileListingPrivate>(sourceName))
@@ -89,7 +93,7 @@ AbstractFileListing::~AbstractFileListing()
 
 void AbstractFileListing::init()
 {
-    executeInit();
+    Q_EMIT askRestoredTracks(sourceName());
 }
 
 void AbstractFileListing::newTrackFile(const MusicAudioTrack &partialTrack)
@@ -101,9 +105,13 @@ void AbstractFileListing::newTrackFile(const MusicAudioTrack &partialTrack)
     }
 }
 
-void AbstractFileListing::resetImportedTracksCounter()
+void AbstractFileListing::restoredTracks(const QString &musicSource, QHash<QUrl, QDateTime> allFiles)
 {
-    d->mImportedTracksCount = 0;
+    if (musicSource == sourceName()) {
+        executeInit(std::move(allFiles));
+
+        refreshContent();
+    }
 }
 
 void AbstractFileListing::applicationAboutToQuit()
@@ -204,19 +212,16 @@ void AbstractFileListing::scanDirectory(QList<MusicAudioTrack> &newFiles, const
             ++d->mImportedTracksCount;
             if (d->mImportedTracksCount % d->mNotificationUpdateInterval == 0) {
                 d->mNotificationUpdateInterval = std::min(50, 1 + d->mNotificationUpdateInterval * 2);
-                Q_EMIT importedTracksCountChanged();
             }
 
             if (newFiles.size() > d->mNewFilesEmitInterval && d->mStopRequest == 0) {
                 d->mNewFilesEmitInterval = std::min(50, 1 + d->mNewFilesEmitInterval * d->mNewFilesEmitInterval);
-                Q_EMIT importedTracksCountChanged();
                 emitNewFiles(newFiles);
                 newFiles.clear();
             }
         }
 
         if (d->mStopRequest == 1) {
-            Q_EMIT importedTracksCountChanged();
             break;
         }
     }
@@ -227,11 +232,6 @@ const QString &AbstractFileListing::sourceName() const
     return d->mSourceName;
 }
 
-int AbstractFileListing::importedTracksCount() const
-{
-    return d->mImportedTracksCount;
-}
-
 void AbstractFileListing::directoryChanged(const QString &path)
 {
     const auto directoryEntry = d->mDiscoveredFiles.find(QUrl::fromLocalFile(path));
@@ -243,7 +243,7 @@ void AbstractFileListing::directoryChanged(const QString &path)
 
     scanDirectoryTree(path);
 
-    Q_EMIT indexingFinished(d->mImportedTracksCount);
+    Q_EMIT indexingFinished();
 }
 
 void AbstractFileListing::fileChanged(const QString &modifiedFileName)
@@ -257,8 +257,9 @@ void AbstractFileListing::fileChanged(const QString &modifiedFileName)
     }
 }
 
-void AbstractFileListing::executeInit()
+void AbstractFileListing::executeInit(QHash<QUrl, QDateTime> allFiles)
 {
+    d->mAllFiles = std::move(allFiles);
 }
 
 void AbstractFileListing::triggerRefreshOfContent()
@@ -275,10 +276,30 @@ MusicAudioTrack AbstractFileListing::scanOneFile(const QUrl &scanFile)
 {
     MusicAudioTrack newTrack;
 
+    auto localFileName = scanFile.toLocalFile();
+
+    const auto &fileMimeType = d->mMimeDb.mimeTypeForFile(localFileName);
+    if (!fileMimeType.name().startsWith(QStringLiteral("audio/"))) {
+        return newTrack;
+    }
+
+    QFileInfo scanFileInfo(localFileName);
+
+    if (scanFileInfo.exists()) {
+        auto itExistingFile = d->mAllFiles.find(scanFile);
+        if (itExistingFile != d->mAllFiles.end()) {
+            if (*itExistingFile >= scanFileInfo.fileTime(QFile::FileModificationTime)) {
+                d->mAllFiles.erase(itExistingFile);
+                return newTrack;
+            }
+        }
+    }
+
     newTrack = ElisaUtils::scanOneFile(scanFile, d->mMimeDb, d->mExtractors);
 
     if (newTrack.isValid()) {
-        QFileInfo scanFileInfo(scanFile.toLocalFile());
+        newTrack.setFileModificationTime(scanFileInfo.fileTime(QFile::FileModificationTime));
+
         if (scanFileInfo.exists()) {
             watchPath(scanFile.toLocalFile());
         }
@@ -289,7 +310,11 @@ MusicAudioTrack AbstractFileListing::scanOneFile(const QUrl &scanFile)
 
 void AbstractFileListing::watchPath(const QString &pathName)
 {
-    d->mFileSystemWatcher.addPath(pathName);
+    if (!d->mFileSystemWatcher.addPath(pathName)) {
+        Q_EMIT errorWatchingFiles();
+
+        qDebug() << "AbstractFileListing::watchPath" << "fail for" << pathName;
+    }
 }
 
 void AbstractFileListing::addFileInDirectory(const QUrl &newFile, const QUrl &directoryName)
@@ -325,7 +350,6 @@ void AbstractFileListing::scanDirectoryTree(const QString &path)
     scanDirectory(newFiles, QUrl::fromLocalFile(path));
 
     if (!newFiles.isEmpty() && d->mStopRequest == 0) {
-        Q_EMIT importedTracksCountChanged();
         emitNewFiles(newFiles);
     }
 }
@@ -349,9 +373,16 @@ void AbstractFileListing::addCover(const MusicAudioTrack &newTrack)
 
     QFileInfo trackFilePath(newTrack.resourceURI().toLocalFile());
     QDir trackFileDir = trackFilePath.absoluteDir();
+    QString dirNamePattern = QStringLiteral("*") + trackFileDir.dirName() + QStringLiteral("*");
     QStringList filters;
-    filters << QStringLiteral("cover.jpg") << QStringLiteral("cover.png")
-            << QStringLiteral("folder.jpg") << QStringLiteral("folder.png");
+    filters << QStringLiteral("*[Cc]over*.jpg") << QStringLiteral("*[Cc]over*.png")
+            << QStringLiteral("*[Ff]older*.jpg") << QStringLiteral("*[Ff]older*.png")
+            << QStringLiteral("*[Ff]ront*.jpg") << QStringLiteral("*[Ff]ront*.png")
+            << dirNamePattern + QStringLiteral(".jpg") << dirNamePattern + QStringLiteral(".png")
+            << dirNamePattern.toLower() + QStringLiteral(".jpg") << dirNamePattern.toLower() + QStringLiteral(".png");
+    dirNamePattern.remove(QLatin1Char(' '));
+    filters << dirNamePattern + QStringLiteral(".jpg") << dirNamePattern + QStringLiteral(".png")
+            << dirNamePattern.toLower() + QStringLiteral(".jpg") << dirNamePattern.toLower() + QStringLiteral(".png");
     trackFileDir.setNameFilters(filters);
     QFileInfoList coverFiles = trackFileDir.entryInfoList();
     if (coverFiles.isEmpty()) {
@@ -395,9 +426,22 @@ void AbstractFileListing::setSourceName(const QString &name)
     d->mSourceName = name;
 }
 
-void AbstractFileListing::increaseImportedTracksCount()
+QHash<QUrl, QDateTime> &AbstractFileListing::allFiles()
 {
-    ++d->mImportedTracksCount;
+    return d->mAllFiles;
+}
+
+void AbstractFileListing::checkFilesToRemove()
+{
+    QList<QUrl> allRemovedFiles;
+
+    for (auto itFile = d->mAllFiles.begin(); itFile != d->mAllFiles.end(); ++itFile) {
+        allRemovedFiles.push_back(itFile.key());
+    }
+
+    if (!allRemovedFiles.isEmpty()) {
+        Q_EMIT removedTracksList(allRemovedFiles);
+    }
 }
 
 
