@@ -20,7 +20,10 @@
 #ifndef ELISAUTILS_H
 #define ELISAUTILS_H
 
+#include "elisaLib_export.h"
+
 #include "musicaudiotrack.h"
+#include <KFileMetaData/Properties>
 
 #include <QUrl>
 #include <QMimeDatabase>
@@ -36,8 +39,10 @@ namespace ElisaUtils {
 
 Q_NAMESPACE
 
-MusicAudioTrack scanOneFile(const QUrl &scanFile, const QMimeDatabase &mimeDatabase,
-                            const KFileMetaData::ExtractorCollection &allExtractors);
+ELISALIB_EXPORT MusicAudioTrack scanOneFile(const QUrl &scanFile, const QMimeDatabase &mimeDatabase,
+                                            const KFileMetaData::ExtractorCollection &allExtractors);
+
+ELISALIB_EXPORT void scanProperties(const QString localFileName, const KFileMetaData::PropertyMap &allProperties, MusicAudioTrack &trackData);
 
 enum PlayListEnqueueMode {
     AppendPlayList,
@@ -53,6 +58,41 @@ enum PlayListEnqueueTriggerPlay {
 
 Q_ENUM_NS(PlayListEnqueueTriggerPlay)
 
+enum ColumnsRoles {
+    TitleRole = Qt::UserRole + 1,
+    SecondaryTextRole,
+    ImageUrlRole,
+    ShadowForImageRole,
+    ChildModelRole,
+    DurationRole,
+    MilliSecondsDurationRole,
+    ArtistRole,
+    AllArtistsRole,
+    HighestTrackRating,
+    AlbumRole,
+    AlbumArtistRole,
+    TrackNumberRole,
+    DiscNumberRole,
+    RatingRole,
+    GenreRole,
+    LyricistRole,
+    ComposerRole,
+    CommentRole,
+    YearRole,
+    ChannelsRole,
+    BitRateRole,
+    SampleRateRole,
+    ImageRole,
+    ResourceRole,
+    IdRole,
+    DatabaseIdRole,
+    IsSingleDiscAlbumRole,
+    ContainerDataRole,
+    IsPartialDataRole,
+};
+
+Q_ENUM_NS(ColumnsRoles)
+
 }
 
 #endif // ELISAUTILS_H
