@@ -19,6 +19,7 @@
 
 #include "musicaudiotrack.h"
 
+#include <QDateTime>
 #include <QDebug>
 #include <utility>
 
@@ -26,23 +27,25 @@ class MusicAudioTrackPrivate
 {
 public:
 
-    MusicAudioTrackPrivate()
-    {
-    }
+    MusicAudioTrackPrivate() = default;
 
     MusicAudioTrackPrivate(bool aValid, QString aId, QString aParentId,
                            QString aTitle, QString aArtist, QString aAlbumName, QString aAlbumArtist,
                            int aTrackNumber, int aDiscNumber, QTime aDuration, QUrl aResourceURI,
-                           QUrl aAlbumCover, int rating, bool aIsSingleDiscAlbum)
+                           const QDateTime &fileModificationTime, QUrl aAlbumCover, int rating,
+                           bool aIsSingleDiscAlbum, QString aGenre, QString aComposer,
+                           QString aLyricist)
         : mId(std::move(aId)), mParentId(std::move(aParentId)), mTitle(std::move(aTitle)), mArtist(std::move(aArtist)),
-          mAlbumName(std::move(aAlbumName)), mAlbumArtist(std::move(aAlbumArtist)), mTrackNumber(aTrackNumber),
-          mDiscNumber(aDiscNumber), mDuration(aDuration), mResourceURI(std::move(aResourceURI)),
-          mAlbumCover(std::move(aAlbumCover)), mRating(rating), mIsValid(aValid), mIsSingleDiscAlbum(aIsSingleDiscAlbum)
+          mAlbumName(std::move(aAlbumName)), mAlbumArtist(std::move(aAlbumArtist)),
+          mGenre(std::move(aGenre)), mComposer(std::move(aComposer)), mLyricist(std::move(aLyricist)),
+          mResourceURI(std::move(aResourceURI)),
+          mAlbumCover(std::move(aAlbumCover)), mDuration(aDuration),
+          mFileModificationTime(fileModificationTime),
+          mTrackNumber(aTrackNumber), mDiscNumber(aDiscNumber), mRating(rating),
+          mIsValid(aValid), mIsSingleDiscAlbum(aIsSingleDiscAlbum)
     {
     }
 
-    qulonglong mDatabaseId = 0;
-
     QString mId;
 
     QString mParentId;
@@ -63,6 +66,16 @@ public:
 
     QString mComment;
 
+    QUrl mResourceURI;
+
+    QUrl mAlbumCover;
+
+    qulonglong mDatabaseId = 0;
+
+    QTime mDuration;
+
+    QDateTime mFileModificationTime;
+
     int mTrackNumber = -1;
 
     int mDiscNumber = -1;
@@ -75,12 +88,6 @@ public:
 
     int mYear = 0;
 
-    QTime mDuration;
-
-    QUrl mResourceURI;
-
-    QUrl mAlbumCover;
-
     int mRating = -1;
 
     bool mIsValid = false;
@@ -93,14 +100,18 @@ MusicAudioTrack::MusicAudioTrack() : d(std::make_unique<MusicAudioTrackPrivate>(
 {
 }
 
-MusicAudioTrack::MusicAudioTrack(bool aValid, const QString &aId, const QString &aParentId,
-                                 const QString &aTitle, const QString &aArtist, const QString &aAlbumName,
-                                 const QString &aAlbumArtist, int aTrackNumber, int aDiscNumber,
-                                 QTime aDuration, const QUrl &aResourceURI, const QUrl &aAlbumCover, int rating,
-                                 bool aIsSingleDiscAlbum)
-    : d(std::make_unique<MusicAudioTrackPrivate>(aValid, aId, aParentId, aTitle, aArtist, aAlbumName, aAlbumArtist,
-                                                 aTrackNumber, aDiscNumber, aDuration, aResourceURI, aAlbumCover, rating,
-                                                 aIsSingleDiscAlbum))
+MusicAudioTrack::MusicAudioTrack(bool aValid, QString aId, QString aParentId, QString aTitle, QString aArtist, QString aAlbumName,
+                                 QString aAlbumArtist, int aTrackNumber, int aDiscNumber, QTime aDuration, QUrl aResourceURI,
+                                 const QDateTime &fileModificationTime, QUrl aAlbumCover, int rating, bool aIsSingleDiscAlbum,
+                                 QString aGenre, QString aComposer, QString aLyricist)
+    : d(std::make_unique<MusicAudioTrackPrivate>(aValid, std::move(aId), std::move(aParentId),
+                                                 std::move(aTitle), std::move(aArtist),
+                                                 std::move(aAlbumName), std::move(aAlbumArtist),
+                                                 aTrackNumber, aDiscNumber, std::move(aDuration),
+                                                 std::move(aResourceURI), fileModificationTime,
+                                                 std::move(aAlbumCover), rating,
+                                                 aIsSingleDiscAlbum, std::move(aGenre),
+                                                 std::move(aComposer), std::move(aLyricist)))
 {
 }
 
@@ -147,6 +158,7 @@ bool MusicAudioTrack::operator ==(const MusicAudioTrack &other) const
             d->mAlbumName == other.d->mAlbumName && d->mAlbumArtist == other.d->mAlbumArtist &&
             d->mTrackNumber == other.d->mTrackNumber && d->mDiscNumber == other.d->mDiscNumber &&
             d->mDuration == other.d->mDuration && d->mResourceURI == other.d->mResourceURI &&
+            d->mFileModificationTime == other.d->mFileModificationTime &&
             d->mAlbumCover == other.d->mAlbumCover && d->mRating == other.d->mRating &&
             d->mGenre == other.d->mGenre && d->mComposer == other.d->mComposer &&
             d->mLyricist == other.d->mLyricist && d->mComment == other.d->mComment &&
@@ -161,6 +173,7 @@ bool MusicAudioTrack::operator !=(const MusicAudioTrack &other) const
             d->mAlbumName != other.d->mAlbumName || d->mAlbumArtist != other.d->mAlbumArtist ||
             d->mTrackNumber != other.d->mTrackNumber || d->mDiscNumber != other.d->mDiscNumber ||
             d->mDuration != other.d->mDuration || d->mResourceURI != other.d->mResourceURI ||
+            d->mFileModificationTime != other.d->mFileModificationTime ||
             d->mAlbumCover != other.d->mAlbumCover || d->mRating != other.d->mRating ||
             d->mGenre != other.d->mGenre || d->mComposer != other.d->mComposer ||
             d->mLyricist != other.d->mLyricist || d->mComment != other.d->mComment ||
@@ -373,6 +386,16 @@ QTime MusicAudioTrack::duration() const
     return d->mDuration;
 }
 
+void MusicAudioTrack::setFileModificationTime(const QDateTime &value)
+{
+    d->mFileModificationTime = value;
+}
+
+const QDateTime &MusicAudioTrack::fileModificationTime() const
+{
+    return d->mFileModificationTime;
+}
+
 void MusicAudioTrack::setResourceURI(const QUrl &value)
 {
     d->mResourceURI = value;
@@ -405,6 +428,6 @@ bool MusicAudioTrack::isSingleDiscAlbum() const
 
 QDebug operator<<(QDebug stream, const MusicAudioTrack &data)
 {
-    stream << data.title() << data.artist() << data.albumName() << data.albumArtist() << data.duration();
+    stream << data.title() << data.artist() << data.albumName() << data.albumArtist() << data.duration() << data.resourceURI();
     return stream;
 }
