@@ -20,6 +20,8 @@
 #ifndef MUSICAUDIOTRACK_H
 #define MUSICAUDIOTRACK_H
 
+#include "elisaLib_export.h"
+
 #include <QString>
 #include <QTime>
 #include <QUrl>
@@ -30,16 +32,17 @@
 class MusicAudioTrackPrivate;
 class QDebug;
 
-class MusicAudioTrack
+class ELISALIB_EXPORT MusicAudioTrack
 {
 
 public:
 
     MusicAudioTrack();
 
-    MusicAudioTrack(bool aValid, const QString &aId, const QString &aParentId, const QString &aTitle, const QString &aArtist, const QString &aAlbumName,
-                    const QString &aAlbumArtist, int aTrackNumber, int aDiscNumber, QTime aDuration, const QUrl &aResourceURI,
-                    const QUrl &aAlbumCover, int rating, bool aIsSingleDiscAlbum);
+    MusicAudioTrack(bool aValid, QString aId, QString aParentId, QString aTitle, QString aArtist, QString aAlbumName,
+                    QString aAlbumArtist, int aTrackNumber, int aDiscNumber, QTime aDuration, QUrl aResourceURI,
+                    const QDateTime &fileModificationTime, QUrl aAlbumCover, int rating, bool aIsSingleDiscAlbum,
+                    QString aGenre, QString aComposer, QString aLyricist);
 
     MusicAudioTrack(MusicAudioTrack &&other);
 
@@ -139,6 +142,10 @@ public:
 
     QTime duration() const;
 
+    void setFileModificationTime(const QDateTime &value);
+
+    const QDateTime &fileModificationTime() const;
+
     void setResourceURI(const QUrl &value);
 
     const QUrl& resourceURI() const;
