@@ -37,9 +37,6 @@
 #include "notificationitem.h"
 #include "elisaapplication.h"
 #include "elisa_settings.h"
-#include "models/allalbumsmodel.h"
-#include "models/allartistsmodel.h"
-#include "models/alltracksmodel.h"
 #include "models/albummodel.h"
 #include "models/abstractmediaproxymodel.h"
 #include "models/allalbumsproxymodel.h"
@@ -47,6 +44,10 @@
 #include "models/alltracksproxymodel.h"
 #include "models/singleartistproxymodel.h"
 #include "models/singlealbumproxymodel.h"
+#include "models/allalbumsmodel.h"
+#include "models/allartistsmodel.h"
+#include "models/alltracksmodel.h"
+#include "models/allgenresmodel.h"
 
 #include <KI18n/KLocalizedString>
 
@@ -77,7 +78,7 @@ public:
 #endif
 
 #if defined KF5Baloo_FOUND && KF5Baloo_FOUND
-    QScopedPointer<BalooListener> mBalooListener;
+    std::unique_ptr<BalooListener> mBalooListener;
 #endif
 
     std::list<std::unique_ptr<FileListener>> mFileListener;
@@ -86,14 +87,6 @@ public:
 
     QFileSystemWatcher mConfigFileWatcher;
 
-    int mImportedTracksCount = 0;
-
-    int mTotalImportedTracksCount = 0;
-
-    int mActiveMusicListenersCount = 0;
-
-    bool mIndexingRunning = false;
-
     ElisaApplication *mElisaApplication = nullptr;
 
     AllAlbumsModel mAllAlbumsModel;
@@ -102,8 +95,20 @@ public:
 
     AllTracksModel mAllTracksModel;
 
+    AllGenresModel mAllGenresModel;
+
+    //GenericDataModel mAllComposersModel;
+
+    //GenericDataModel mAllLyricistsModel;
+
     AlbumModel mAlbumModel;
 
+    int mImportedTracksCount = 0;
+
+    int mActiveMusicListenersCount = 0;
+
+    bool mIndexingRunning = false;
+
     bool mIndexerBusy = false;
 
 };
@@ -130,25 +135,6 @@ MusicListenersManager::MusicListenersManager(QObject *parent)
     QMetaObject::invokeMethod(&d->mDatabaseInterface, "init", Qt::QueuedConnection,
                               Q_ARG(QString, QStringLiteral("listeners")), Q_ARG(QString, databaseFileName));
 
-    connect(&d->mDatabaseInterface, &DatabaseInterface::artistAdded,
-            this, &MusicListenersManager::artistAdded);
-    connect(&d->mDatabaseInterface, &DatabaseInterface::trackAdded,
-            this, &MusicListenersManager::trackAdded);
-    connect(&d->mDatabaseInterface, &DatabaseInterface::tracksAdded,
-            this, &MusicListenersManager::tracksAdded);
-    connect(&d->mDatabaseInterface, &DatabaseInterface::artistRemoved,
-            this, &MusicListenersManager::artistRemoved);
-    connect(&d->mDatabaseInterface, &DatabaseInterface::albumRemoved,
-            this, &MusicListenersManager::albumRemoved);
-    connect(&d->mDatabaseInterface, &DatabaseInterface::trackRemoved,
-            this, &MusicListenersManager::trackRemoved);
-    connect(&d->mDatabaseInterface, &DatabaseInterface::artistModified,
-            this, &MusicListenersManager::artistModified);
-    connect(&d->mDatabaseInterface, &DatabaseInterface::albumModified,
-            this, &MusicListenersManager::albumModified);
-    connect(&d->mDatabaseInterface, &DatabaseInterface::trackModified,
-            this, &MusicListenersManager::trackModified);
-
     connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit,
             this, &MusicListenersManager::applicationAboutToQuit);
 
@@ -181,8 +167,8 @@ MusicListenersManager::MusicListenersManager(QObject *parent)
     connect(&d->mDatabaseInterface, &DatabaseInterface::albumRemoved,
             &d->mAllAlbumsModel, &AllAlbumsModel::albumRemoved);
 
-    connect(&d->mDatabaseInterface, &DatabaseInterface::artistAdded,
-            &d->mAllArtistsModel, &AllArtistsModel::artistAdded);
+    connect(&d->mDatabaseInterface, &DatabaseInterface::artistsAdded,
+            &d->mAllArtistsModel, &AllArtistsModel::artistsAdded);
     connect(&d->mDatabaseInterface, &DatabaseInterface::artistModified,
             &d->mAllArtistsModel, &AllArtistsModel::artistModified);
     connect(&d->mDatabaseInterface, &DatabaseInterface::artistRemoved,
@@ -195,6 +181,13 @@ MusicListenersManager::MusicListenersManager(QObject *parent)
     connect(&d->mDatabaseInterface, &DatabaseInterface::trackRemoved,
             &d->mAllTracksModel, &AllTracksModel::trackRemoved);
 
+    connect(&d->mDatabaseInterface, &DatabaseInterface::genresAdded,
+            &d->mAllGenresModel, &AllGenresModel::genresAdded);
+    /*connect(&d->mDatabaseInterface, &DatabaseInterface::trackModified,
+            &d->mAllGenresModel, &AllTracksModel::trackModified);
+    connect(&d->mDatabaseInterface, &DatabaseInterface::trackRemoved,
+            &d->mAllGenresModel, &AllTracksModel::trackRemoved);*/
+
     connect(&d->mDatabaseInterface, &DatabaseInterface::albumModified,
             &d->mAlbumModel, &AlbumModel::albumModified);
     connect(&d->mDatabaseInterface, &DatabaseInterface::albumRemoved,
@@ -203,6 +196,9 @@ MusicListenersManager::MusicListenersManager(QObject *parent)
             &d->mDatabaseInterface, &DatabaseInterface::getAlbumFromAlbumId);
     connect(&d->mDatabaseInterface, &DatabaseInterface::sentAlbumData,
             &d->mAlbumModel, &AlbumModel::setAlbumData);
+
+    connect(&d->mDatabaseInterface, &DatabaseInterface::tracksAdded,
+            this, &MusicListenersManager::increaseImportedTracksCount);
 }
 
 MusicListenersManager::~MusicListenersManager()
@@ -215,22 +211,23 @@ DatabaseInterface *MusicListenersManager::viewDatabase() const
 
 void MusicListenersManager::subscribeForTracks(MediaPlayList *client)
 {
-    auto helper = new TracksListener(&d->mDatabaseInterface);
+    auto helper = std::make_unique<TracksListener>(&d->mDatabaseInterface);
 
     helper->moveToThread(&d->mDatabaseThread);
-    connect(&d->mDatabaseThread, &QThread::finished, helper, &QObject::deleteLater);
+    connect(&d->mDatabaseThread, &QThread::finished, helper.get(), &QObject::deleteLater);
 
-    connect(this, &MusicListenersManager::trackRemoved, helper, &TracksListener::trackRemoved);
-    connect(this, &MusicListenersManager::tracksAdded, helper, &TracksListener::tracksAdded);
-    connect(this, &MusicListenersManager::trackModified, helper, &TracksListener::trackModified);
+    connect(&d->mDatabaseInterface, &DatabaseInterface::trackRemoved, helper.get(), &TracksListener::trackRemoved);
+    connect(&d->mDatabaseInterface, &DatabaseInterface::tracksAdded, helper.get(), &TracksListener::tracksAdded);
+    connect(&d->mDatabaseInterface, &DatabaseInterface::trackModified, helper.get(), &TracksListener::trackModified);
     connect(this, &MusicListenersManager::removeTracksInError, &d->mDatabaseInterface, &DatabaseInterface::removeTracksList);
-    connect(helper, &TracksListener::trackHasChanged, client, &MediaPlayList::trackChanged);
-    connect(helper, &TracksListener::trackHasBeenRemoved, client, &MediaPlayList::trackRemoved);
-    connect(helper, &TracksListener::albumAdded, client, &MediaPlayList::albumAdded);
-    connect(client, &MediaPlayList::newTrackByIdInList, helper, &TracksListener::trackByIdInList);
-    connect(client, &MediaPlayList::newTrackByNameInList, helper, &TracksListener::trackByNameInList);
-    connect(client, &MediaPlayList::newTrackByFileNameInList, helper, &TracksListener::trackByFileNameInList);
-    connect(client, &MediaPlayList::newArtistInList, helper, &TracksListener::newArtistInList);
+    connect(helper.get(), &TracksListener::trackHasChanged, client, &MediaPlayList::trackChanged);
+    connect(helper.get(), &TracksListener::trackHasBeenRemoved, client, &MediaPlayList::trackRemoved);
+    connect(helper.get(), &TracksListener::albumAdded, client, &MediaPlayList::albumAdded);
+    connect(client, &MediaPlayList::newTrackByIdInList, helper.get(), &TracksListener::trackByIdInList);
+    connect(client, &MediaPlayList::newTrackByNameInList, helper.get(), &TracksListener::trackByNameInList);
+    connect(client, &MediaPlayList::newTrackByFileNameInList, helper.get(), &TracksListener::trackByFileNameInList);
+    connect(client, &MediaPlayList::newArtistInList, helper.get(), &TracksListener::newArtistInList);
+    helper.release();
 }
 
 int MusicListenersManager::importedTracksCount() const
@@ -263,6 +260,21 @@ QAbstractItemModel *MusicListenersManager::allTracksModel() const
     return &d->mAllTracksModel;
 }
 
+QAbstractItemModel *MusicListenersManager::allGenresModel() const
+{
+    return &d->mAllGenresModel;
+}
+
+QAbstractItemModel *MusicListenersManager::allLyricistsModel() const
+{
+    return nullptr;/*&d->mAllLyricistsModel;*/
+}
+
+QAbstractItemModel *MusicListenersManager::allComposersModel() const
+{
+    return nullptr;/*&d->mAllComposersModel;*/
+}
+
 QAbstractItemModel *MusicListenersManager::albumModel() const
 {
     return &d->mAlbumModel;
@@ -301,19 +313,6 @@ void MusicListenersManager::showConfiguration()
     configureAction->trigger();
 }
 
-void MusicListenersManager::resetImportedTracksCounter()
-{
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
-    if (d->mBalooListener) {
-        d->mBalooListener->resetImportedTracksCounter();
-    }
-#endif
-
-    for (const auto &itFileListener : d->mFileListener) {
-        itFileListener->resetImportedTracksCounter();
-    }
-}
-
 void MusicListenersManager::setElisaApplication(ElisaApplication *elisaApplication)
 {
     if (d->mElisaApplication == elisaApplication) {
@@ -349,27 +348,23 @@ void MusicListenersManager::configChanged()
 
 #if defined KF5Baloo_FOUND && KF5Baloo_FOUND
     if (currentConfiguration->balooIndexer() && !d->mBalooListener) {
-        d->mBalooListener.reset(new BalooListener);
+        d->mBalooListener = std::make_unique<BalooListener>();
         d->mBalooListener->moveToThread(&d->mListenerThread);
         d->mBalooListener->setDatabaseInterface(&d->mDatabaseInterface);
         connect(this, &MusicListenersManager::applicationIsTerminating,
-                d->mBalooListener.data(), &BalooListener::applicationAboutToQuit, Qt::DirectConnection);
-        connect(d->mBalooListener.data(), &BalooListener::indexingStarted,
+                d->mBalooListener.get(), &BalooListener::applicationAboutToQuit, Qt::DirectConnection);
+        connect(d->mBalooListener.get(), &BalooListener::indexingStarted,
                 this, &MusicListenersManager::monitorStartingListeners);
-        connect(d->mBalooListener.data(), &BalooListener::indexingFinished,
+        connect(d->mBalooListener.get(), &BalooListener::indexingFinished,
                 this, &MusicListenersManager::monitorEndingListeners);
-        connect(d->mBalooListener.data(), &BalooListener::clearDatabase,
+        connect(d->mBalooListener.get(), &BalooListener::clearDatabase,
                 &d->mDatabaseInterface, &DatabaseInterface::removeAllTracksFromSource);
-        connect(d->mBalooListener.data(), &BalooListener::importedTracksCountChanged,
-                this, &MusicListenersManager::computeImportedTracksCount);
-        connect(d->mBalooListener.data(), &BalooListener::newNotification,
+        connect(d->mBalooListener.get(), &BalooListener::newNotification,
                 this, &MusicListenersManager::newNotification);
-        connect(d->mBalooListener.data(), &BalooListener::closeNotification,
+        connect(d->mBalooListener.get(), &BalooListener::closeNotification,
                 this, &MusicListenersManager::closeNotification);
-
-        QMetaObject::invokeMethod(d->mBalooListener.data(), "performInitialScan", Qt::QueuedConnection);
     } else if (!currentConfiguration->balooIndexer() && d->mBalooListener) {
-        QMetaObject::invokeMethod(d->mBalooListener.data(), "quitListener", Qt::QueuedConnection);
+        QMetaObject::invokeMethod(d->mBalooListener.get(), "quitListener", Qt::QueuedConnection);
         d->mBalooListener.reset();
     }
 #endif
@@ -409,8 +404,6 @@ void MusicListenersManager::configChanged()
                         this, &MusicListenersManager::monitorStartingListeners);
                 connect(newFileIndexer.get(), &FileListener::indexingFinished,
                         this, &MusicListenersManager::monitorEndingListeners);
-                connect(newFileIndexer.get(), &FileListener::importedTracksCountChanged,
-                        this, &MusicListenersManager::computeImportedTracksCount);
                 connect(newFileIndexer.get(), &FileListener::newNotification,
                         this, &MusicListenersManager::newNotification);
                 connect(newFileIndexer.get(), &FileListener::closeNotification,
@@ -418,29 +411,15 @@ void MusicListenersManager::configChanged()
 
                 newFileIndexer->setRootPath(oneRootPath);
 
-                QMetaObject::invokeMethod(newFileIndexer.get(), "performInitialScan", Qt::QueuedConnection);
-
                 d->mFileListener.emplace_back(std::move(newFileIndexer));
             }
         }
     }
 }
 
-void MusicListenersManager::computeImportedTracksCount()
+void MusicListenersManager::increaseImportedTracksCount(const QList<MusicAudioTrack> &allTracks)
 {
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
-    if (d->mBalooListener) {
-        d->mImportedTracksCount = d->mBalooListener->importedTracksCount();
-    } else {
-        d->mImportedTracksCount = 0;
-    }
-#else
-    d->mImportedTracksCount = 0;
-#endif
-
-    for (const auto &itFileListener : d->mFileListener) {
-        d->mImportedTracksCount += itFileListener->importedTracksCount();
-    }
+    d->mImportedTracksCount += allTracks.size();
 
     if (d->mImportedTracksCount && d->mIndexerBusy) {
         d->mIndexerBusy = false;
@@ -454,6 +433,13 @@ void MusicListenersManager::computeImportedTracksCount()
     Q_EMIT importedTracksCountChanged();
 }
 
+void MusicListenersManager::decreaseImportedTracksCount()
+{
+    --d->mImportedTracksCount;
+
+    Q_EMIT importedTracksCountChanged();
+}
+
 void MusicListenersManager::monitorStartingListeners()
 {
     if (d->mActiveMusicListenersCount == 0) {
@@ -464,14 +450,12 @@ void MusicListenersManager::monitorStartingListeners()
     ++d->mActiveMusicListenersCount;
 }
 
-void MusicListenersManager::monitorEndingListeners(int tracksCount)
+void MusicListenersManager::monitorEndingListeners()
 {
     --d->mActiveMusicListenersCount;
 
-    d->mTotalImportedTracksCount += tracksCount;
-
     if (d->mActiveMusicListenersCount == 0) {
-        if (d->mTotalImportedTracksCount < 4 && d->mElisaApplication) {
+        if (d->mImportedTracksCount < 4 && d->mElisaApplication) {
             NotificationItem notEnoughTracks;
 
             notEnoughTracks.setNotificationId(QStringLiteral("notEnoughTracks"));
@@ -492,7 +476,7 @@ void MusicListenersManager::monitorEndingListeners(int tracksCount)
         d->mIndexingRunning = false;
         Q_EMIT indexingRunningChanged();
 
-        QMetaObject::invokeMethod(&d->mDatabaseInterface, "cleanInvalidTracks", Qt::QueuedConnection);
+        //QMetaObject::invokeMethod(&d->mDatabaseInterface, "cleanInvalidTracks", Qt::QueuedConnection);
     }
 }
 
